[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - couchdb.client.PreconditionFailed: Exception raised when a 412 HTTP error is received in response to a request.
      - couchdb.client.ResourceConflict: Exception raised when a 409 HTTP error is received in response to a request.
      - couchdb.client.ResourceNotFound: Exception raised when a 404 HTTP error is received in response to a request.
      - couchdb.client.ServerError: Exception raised when an unexpected HTTP error is received in response to a request.
  - couchdb.client.Database: Representation of a database on a CouchDB server.
  - couchdb.schema.Field: Basic unit for mapping a piece of data between Python and JSON.
    - couchdb.schema.BooleanField: Schema field for boolean values.
    - couchdb.schema.DateField: Schema field for storing dates.
    - couchdb.schema.DateTimeField: Schema field for storing date/time values.
    - couchdb.schema.DecimalField: Schema field for decimal values.
    - couchdb.schema.DictField: Field type for nested dictionaries.
    - couchdb.schema.FloatField: Schema field for float values.
    - couchdb.schema.IntegerField: Schema field for integer values.
    - couchdb.schema.ListField: Field type for sequences of other fields.
    - couchdb.schema.LongField: Schema field for long integer values.
    - couchdb.schema.TextField: Schema field for string values.
    - couchdb.schema.TimeField: Schema field for storing times.
  - couchdb.tools.replication_helper.ReplicationHelper: Listener daemon for CouchDB database notifications
  - couchdb.schema.Schema
    - couchdb.schema.Document
  - couchdb.client.Server: Representation of a CouchDB server.
  - couchdb.design.ViewDefinition: Definition of a view stored in a specific design document.
  - couchdb.client.ViewResults: Representation of a parameterized view (either permanent or temporary) and the results it produces.
  - dict: dict() -> new empty dictionary.
    - couchdb.client.Document: Representation of a document in the database.
    - couchdb.client.Row: Representation of a row as returned by database views.
  - list: list() -> new list list(sequence) -> new list initialized from sequence's items
    - couchdb.schema.ListField.Proxy
  - type: type(object) -> the object's type type(name, bases, dict) -> a new type
    - couchdb.schema.SchemaMeta
      - couchdb.schema.DocumentMeta